@@ -24,6 +24,7 @@
 
 #include <config.h>
 #include <string.h>
+#include <ctype.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
 #include "paths.h"
@@ -195,7 +196,7 @@ remove_application (SpiRegistry *reg, DBusConnection *bus, guint index)
 {
   SpiReference *ref = g_ptr_array_index (reg->apps, index);
 
-  /*TODO spi_remove_device_listeners (registry->de_controller, old);*/
+  spi_remove_device_listeners (reg->dec, ref->name);
   children_removed_listener (bus, index, ref->name, ref->path);
   g_ptr_array_remove_index (reg->apps, index);
 }
@@ -348,7 +349,7 @@ signal_filter (DBusConnection *bus, DBusMessage *message, void *user_data)
   const char *member = dbus_message_get_member (message);
 
   if (type != DBUS_MESSAGE_TYPE_SIGNAL)
-    return;
+    return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 
   if (!g_strcmp0(iface, DBUS_INTERFACE_DBUS) &&
       !g_strcmp0(member, "NameOwnerChanged"))
@@ -839,18 +840,18 @@ impl_register_event (DBusConnection *bus, DBusMessage *message, void *user_data)
 
   if (!dbus_message_get_args (message, NULL, DBUS_TYPE_STRING, &orig_name,
     DBUS_TYPE_INVALID))
-    return;
+    return NULL;
 
   name = ensure_proper_format (orig_name);
 
   evdata = (event_data *) g_malloc (sizeof (*evdata));
   if (!evdata)
-    return;
+    return NULL;
   data = g_strsplit (name, ":", 3);
   if (!data)
     {
       g_free (evdata);
-      return;
+      return NULL;
     }
   if (!data [0])
     data [1] = NULL;
@@ -889,7 +890,7 @@ impl_deregister_event (DBusConnection *bus, DBusMessage *message, void *user_dat
 
   if (!dbus_message_get_args (message, NULL, DBUS_TYPE_STRING, &orig_name,
     DBUS_TYPE_INVALID))
-    return;
+    return NULL;
   name = ensure_proper_format (orig_name);
 
   remove_events (registry, sender, name);
@@ -1312,6 +1313,7 @@ handle_method_cache (DBusConnection *bus, DBusMessage *message, void *user_data)
       dbus_connection_send (bus, reply, NULL);
       dbus_message_unref (reply);
     }
+  return result;
 }
 
 static DBusHandlerResult
